<?php
# Copyright (C) 2006 Greg Sabino Mullane <greg@turnstep.com>
# http://www.mediawiki.org/
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
# http://www.gnu.org/copyleft/gpl.html

/**
 * Search engine hook base class for Cubrid
 * @package MediaWiki
 * @subpackage Search
 */

/** @package MediaWiki */
class SearchCubrid extends SearchEngine {

	function SearchCubrid( &$db ) {
		$this->db =& $db;
	}

	function searchText( $term ) {
	  $terms = array();
	  $terms[]=$term;
		$resultSet = $this->db->resultObject( $this->db->query( $this->searchQuery( $term, 'text' ) ) );
		return new CubridSearchResultSet( $resultSet, $terms );
	}
	function searchTitle( $term ) {
	  $terms = array();
	  $terms[]=$term;
		$resultSet = $this->db->resultObject( $this->db->query( $this->searchQuery( $term, 'title' ) ) );
		return new CubridSearchResultSet( $resultSet, $terms );
	}


	/**
	 * Construct the full SQL query to do the search.
	 * @param string $filteredTerm
	 * @param string $fulltext
	 * @private
	 */
	function searchQuery( $term, $type ) {
	  if ($type=="text") {
  		$query = "SELECT page_id, page_namespace, page_title, old_text AS page_text ".
  			"FROM page p, revision r, text c WHERE p.page_latest = r.rev_id " .
  			"AND r.rev_text_id = c.old_id AND c.old_text like '%".$term."%' ";
  	} else {
  		$query = "SELECT page_id, page_namespace, page_title, old_text AS page_text ".
  			"FROM page p, revision r, text c WHERE p.page_latest = r.rev_id " .
  			"AND r.rev_text_id = c.old_id AND p.page_title like '%".$term."%' ";
  	}
  	

		## Redirects
		if (! $this->showRedirects)
			$query .= ' AND page_is_redirect = 0'; ## IS FALSE

		## Namespaces - defaults to 0
		if ( count($this->namespaces) < 1)
			$query .= ' AND page_namespace = 0';
		else {
			$namespaces = implode( ',', $this->namespaces );
			$query .=  " AND page_namespace IN ($namespaces)";
		}

		$query .= " ORDER BY page_id DESC";

		$query = $this->db->limitResult( $query, $this->limit, $this->offset );

		return $query;
	}

} ## end of the SearchCubrid class


/** @package MediaWiki */
class CubridSearchResultSet extends SearchResultSet {
	function CubridSearchResultSet( $resultSet, $terms ) {
		$this->mResultSet = $resultSet;
		$this->mTerms = $terms;
	}

	function termMatches() {
		return $this->mTerms;
	}

	function numRows() {
		return $this->mResultSet->numRows();
	}

	function next() {
		$row = $this->mResultSet->fetchObject();
		if( $row === false || $row == null) {
			return false;
		} else {
			return new SearchResult( $row );
		}
	}
}

?>
